==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Çalışma</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Yaşam</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Diğer</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Başlamadan bir gün önce</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Bana yarın hatırlat</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Bana daha sonra hatırlat</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 Dakika sonra</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 Saat sonra</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 Saat sonra</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Yarın</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Zamanlama hatırlatıcısı</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 ila %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Bugün</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Başlamadan bir gün önce</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Kapat</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Bana yarın hatırlat</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Sonra hatırlat</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Zamanlamalı Hatırlatıcı</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 ile %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Bugün</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Yarın</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Çalışma</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Yaşam</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Diğer</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Başlamadan bir gün önce</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Bana yarın hatırlat</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Bana daha sonra hatırlat</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 Dakika sonra</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 Saat sonra</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 Saat sonra</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Yarın</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Zamanlama hatırlatıcısı</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 ila %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Bugün</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
